@@ -49,7 +49,6 @@ ContactGroupSearchJob::ContactGroupSearchJob( QObject * parent )
                                           "  </query>"
                                           "</request>"
 #else
-                                          "prefix nco:<http://www.semanticdesktop.org/ontologies/2007/03/22/nco#>"
                                           "SELECT ?r WHERE { ?r a nco:ContactGroup }"
 #endif
                                         ) );
@@ -71,10 +70,6 @@ void ContactGroupSearchJob::setQuery( Criterion criterion, const QString &value,
 {
   QString query;
 
-#ifndef AKONADI_USE_STRIGI_SEARCH
-  query = QString::fromLatin1( "prefix nco:<http://www.semanticdesktop.org/ontologies/2007/03/22/nco#>" );
-#endif
-
   if ( match == ExactMatch ) {
     if ( criterion == Name ) {
       query += QString::fromLatin1(
